# Generated by Django 2.1.5 on 2019-02-22 16:31

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bom', '0012_partchangehistory'),
    ]

    operations = [
        migrations.AlterField(
            model_name='partchangehistory',
            name='part_id',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bom.Part'),
        ),
    ]
